@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 our @EXPORT_OK = qw(git_uncommitted_files);
 
@@ -17,12 +17,14 @@ sub git_uncommitted_files {
     my $pushd = pushd( realpath($dir) );
     return
         map { rel2abs($_) }
-        _relevant_files_from_status( capturex(qw( git status --porcelain -z )) );
+        _relevant_files_from_status( capturex(qw( git status --porcelain -z -uno )) );
 }
 
 sub _relevant_files_from_status {
     my ($status) = @_;
 
+    return unless $status;
+
     my @files;
     {
         local $_ = $status;
